==> tetzle_2.2.1.orig.tar.gz: tetzle-2.2.1/translations/tetzle_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Deschide imagine</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Aspect</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opţiuni</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Margini teşite</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Umbrire</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Culori</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fundal:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Umbre:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Evidenţiere:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Lipseşte imagine.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Vă rugăm aşteptaţi</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Încărcare imagine...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Generare puzzle...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Creare piese...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Încărcare puzzle...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Format date necunoscut</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Element necunoscut &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Eroare la analizarea fişierului XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Încărcare piese...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Preluare piese...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Plasare  piese...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Alegere joc</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Joc curent</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Proprietăţi imagine</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nume:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etichete:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Adăugare imagine</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Eliminare imagine</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Proprietăţi imagine</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 piese</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Copiere imagini...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>Eliminaţi imaginea selectată?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Eliminaţi imaginea selectată?

Există jocuri salvate care folosesc această imagine, care vor fi, de asemenea, eliminate.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>FărăTitlu</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>FărăTitlu</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 piese %2 %3% completat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ştergere</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Ştergere joc</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Şterge jocul selectat?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Imagine de ansamblu</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Adăugare etichetă</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Eliminare etichetă</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Neetichetat</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Toate imaginile</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>FărăTitlu %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Elimină eticheta selectată?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>O etichetă cu acel nume deja există.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>P&amp;reluare piese</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>Alegeţi...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vizualizare</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Mărire</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>M&amp;icşorare</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Cel mai potrivit</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Arată imagine de ansamblu</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Tot ecranul</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Aspect...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Limbă...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controale</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controale</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Piese ridicate:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clic stînga sau spaţiu</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Piese coborîte:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Selectare piese:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Glisare stînga</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rotire piese:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Clic dreapta, Control + Clic stînga, sau R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Glisare puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Clic mijloc, Shift + Clic stînga, sau Săgeţi</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mărire puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Rotiţa de derulare or +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mutare cursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Mutare mouse sau W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Despre Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Un puzzle cu tetromino-uri pentru piese</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Toate drepturile rezervate &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation>Selectaţi versiunea OpenGL.</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versiunea</translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> tetzle_3.0.0.orig.tar.gz: tetzle-3.0.0/translations/tetzle_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Deschide imagine</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Aspect</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opţiuni</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Margini teşite</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Umbrire</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Culori</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fundal:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Umbre:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Evidenţiere:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Eroare</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Lipseşte imagine.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Vă rugăm aşteptaţi</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Încărcare imagine...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Generare puzzle...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Creare piese...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Încărcare puzzle...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Format date necunoscut</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Element necunoscut &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Eroare la analizarea fişierului XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Încărcare piese...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Preluare piese...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Plasare  piese...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succes</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Alegere joc</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Joc curent</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Proprietăţi imagine</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nume:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etichete:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selectaţi limba aplicaţiei:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Limbaj Sistem&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notă</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Vă rugăm reporniţi această aplicaţie pentru ca schimbarea limbii să aibă efect.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Adăugare imagine</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Eliminare imagine</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Proprietăţi imagine</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 piese</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Copiere imagini...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulare</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>FărăTitlu</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>FărăTitlu</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 piese %2 %3% completat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ştergere</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Ştergere joc</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Şterge jocul selectat?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Imagine de ansamblu</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Adăugare etichetă</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Eliminare etichetă</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Neetichetat</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Toate imaginile</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>FărăTitlu %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Întrebare</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Elimină eticheta selectată?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Scuze</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>O etichetă cu acel nume deja există.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>P&amp;reluare piese</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ieşire</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>Alegeţi...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vizualizare</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Mărire</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>M&amp;icşorare</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Cel mai potrivit</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Arată imagine de ansamblu</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Tot ecranul</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Setări</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Aspect...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Limbă...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajutor</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controale</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Despre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controale</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Piese ridicate:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clic stînga sau spaţiu</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Piese coborîte:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Selectare piese:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Glisare stînga</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rotire piese:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Clic dreapta, Control + Clic stînga, sau R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Glisare puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Clic mijloc, Shift + Clic stînga, sau Săgeţi</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mărire puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Rotiţa de derulare or +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mutare cursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Mutare mouse sau W,A,D,S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Despre Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Un puzzle cu tetromino-uri pentru piese</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Toate drepturile rezervate &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lansat sub licenţă &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation>%p% complet</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation>Zoom: %1%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation>Imagini de adăugat la dialogul de alegere a jocului.</translation>
    </message>
</context>
</TS>
